Packeter
========

.. autoclass:: snakemq.packeter.Packeter
  :members: __init__, send_packet

Callbacks
+++++++++

.. autoinstanceattribute:: snakemq.packeter.Packeter.on_connect
.. autoinstanceattribute:: snakemq.packeter.Packeter.on_disconnect
.. autoinstanceattribute:: snakemq.packeter.Packeter.on_packet_send
.. autoinstanceattribute:: snakemq.packeter.Packeter.on_packet_recv
